@@ -84,14 +84,13 @@ class SendGrid(object):
         url = self.build_url(api, resource)
         call_params = self.build_params(params or {})
         response = requests.post(url, data=call_params, timeout=60)
-        with open("sendgrid.log", "a") as sendgridlog:
-            sendgridlog.write(str(url) + " " + call_params + " at " + datetime.datetime.now().isoformat() + "\n")
         try:
             response_content = json.loads(response.content)
         except ValueError:
             response_content = {'error': re.search(r'<title>([^<]+)</title>', response.content).group(1)}
 
         with open("sendgrid.log", "a") as sendgridlog:
+            sendgridlog.write(str(url) + " " + json.dumps(call_params) + " at " + datetime.datetime.now().isoformat() + "\n")
             sendgridlog.write(str(response_content) + " at " + datetime.datetime.now().isoformat() + "\n")
 
         return dict(success=True,
